import { createApp } from "vue";
import App from "./App.vue";
import router from "./router";
import store from "./store";
import ElementPlus from "element-plus";

import "element-plus/lib/theme-chalk/index.css";
import "dayjs/locale/zh-cn";
import locale from "element-plus/lib/locale/lang/zh-cn";

import { fetchCurrentUser } from "./service/user";
import { checkPathAuth } from "./utils/authUtil";
import { redirectToLogin, getCookie } from "./utils/util";
import { ElMessage } from "element-plus";

// 处理路由权限
router.beforeResolve(async (to, from, next) => {

  if (!to.meta.requireAuth) {
    next();
    return true;
  }

  if (!store.state.permissions) {
    const { status, user } = await fetchCurrentUser();
    let isDefault = window.localStorage.getItem('isDefault');
    if(isDefault == 2) {
      user.email = getCookie('username');
    }
    if (status === 'success') {
      store.commit('updateUserInfo', user);
      await store.dispatch('updateUserPermission', { email: user.email })
    } else {
      redirectToLogin();
      return false;
    }
  }

  if (!checkPathAuth(to.path)) {
      redirectToLogin();
      return ElMessage("您没有权限");
    // router.push({name: 'Forbidden'})
  } else {
    next();
    return true;
  }
})

createApp(App)
  .use(router)
  .use(store)
  .use(ElementPlus, { locale })
  .mount("#app");
